function getCookie(c_name) {
	var i, x, y, ARRcookies = document.cookie.split(';');
	for (i = 0; i < ARRcookies.length; i++) {
		x = ARRcookies[i].substr(0,ARRcookies[i].indexOf('='));
		y = ARRcookies[i].substr(ARRcookies[i].indexOf('=') + 1);
		x = x.replace(/^\s+|\s+$/g,'');
		if (x == c_name) {
			return unescape(y);
		}
	}
}

function setCookie(c_name, value, exdays) {
	var exdate = new Date();
	exdate.setDate(exdate.getDate() + exdays);
	var c_value = escape(value) + ((exdays == null) ? '' : '; expires=' + exdate.toUTCString());
	document.cookie = c_name + '=' + c_value;
}

function areCookiesSupported() {
	setCookie('cookie', 'true');
	return getCookie('cookie') == 'true';
}

function isHTML5StorageSupported() {
	if (localStorage === undefined) {
		return false;
	}
	
	localStorage.setItem('localStorage', 'true');
	return localStorage.getItem('localStorage') == 'true';
}

function isStorageSupported() {
	return areCookiesSupported() || isHTML5StorageSupported();
}

function store(name, value) {
	if (areCookiesSupported()) {
		setCookie(name, value, 9999);
		return true;
	} else if (isHTML5StorageSupported()) {
		localStorage.setItem(name, value);
		return true;
	}
	
	return false;
}

function load(name) {
	if (areCookiesSupported()) {
		return getCookie(name);
	} else if (isHTML5StorageSupported()) {
		return localStorage.getItem(name);
	}

	return null;
}

/*!
 * Set the cascading style sheet file for this page.
 * @param style the css file to load
 */
function setStyle(style) {
	store('style', style);
	$('#style').attr('href', 'css/' + style);
	$('.styleSelect').val(style);
}

/*!
 * Toggle the display of the preview images for models.
 * @param isVisible if true, show the preview images; otherwise hide the images. Save the setting in both cases. 
 */
function showModelPreviews(isVisible) {
	store('showModelPreviews', isVisible);
	$('.previewModelsCheckBox').attr('checked', isVisible);
	$('th.modelPreview, td.modelPreview').toggle(isVisible);
}

/*!
 * Toggle the display of the preview images for models.
 * @param isVisible if true, show the preview images; otherwise hide the images. Save the setting in both cases. 
 */
function showUnusedEntries(isVisible) {
	store('showUnusedEntries', isVisible);
	$('.showUnusedCheckBox').attr('checked', isVisible);
	$('.unused').toggle(isVisible);
}

function setPageFading(isFading) {

	store('fadePages', isFading);
	$('.fadePagesCheckBox').attr('checked', isFading);
	
	var $content = $('#content');
	var $links = $('a:not([target="_blank"], [href^="mailto:"]), map area:not([target="_blank"], [href^="mailto:"])');
	
	if (isFading) {
		// fade-in effect
		$content.hide();
		$content.fadeIn();
		
		// fade-out effect
		$links.click(function(event){
			event.preventDefault();
			linkLocation = this.href;
			$content.fadeOut(150, redirectPage);		
		});
		
		function redirectPage() {
			window.location = linkLocation;
		}
	} else {
		$links.unbind('click');
	}
}

/*!
 * Toggle the draggable option elements
 * @param isDraggable if true, show make content elements draggable; otherwise remove the drag function. 
 */
function setDraggable(isDraggable) {
	store('isDraggable', isDraggable);
	$('.setDraggableCheckBox').attr('checked', isDraggable);
	
	var $drag = $('.draggable, .tablesWrapper table');
	$drag.draggable("option", "disabled", !isDraggable);
}

/*!
 * Load the settings saved in cookies.
 */
function loadSettings() {

	// Load the style.
	var style = load('style');
	if (style != null && style != '' && style != 'undefined') {
		setStyle(style);
	}
	
	// Toggle smooth page transitions.
	var fadePagesCookie = load('fadePages');
	var isPageFading = fadePagesCookie == 'true';
	setPageFading(isPageFading);
	
	// Toggle model previews.
	var modelPreviewsCookie = load('showModelPreviews');
	var arePreviewsVisible = modelPreviewsCookie == null || modelPreviewsCookie == '' || modelPreviewsCookie == 'true';
	showModelPreviews(arePreviewsVisible);
	
	// Toggle unused entries' display.
	var showUnusedCookie = load('showUnusedEntries');
	var areUnusedVisible = showUnusedCookie == null || showUnusedCookie == '' || showUnusedCookie == 'true';
	showUnusedEntries(areUnusedVisible);
	
	// Toggle drag method for elements.
	var isDraggableCookie = load('isDraggable');
	var isDraggable = isDraggableCookie == 'true';
	setDraggable(isDraggable);
}

$(function() {

	$('.draggable, .tablesWrapper table').draggable({ disabled: true });

	// Load the CSS file.
	loadSettings();

	$('.fadePagesCheckBox').change(function() {
		setPageFading(this.checked);
	});

	$('.previewModelsCheckBox').change(function() {
		showModelPreviews(this.checked);
	});
	
	$('.showUnusedCheckBox').change(function() {
		showUnusedEntries(this.checked);
	});
	
	$('.setDraggableCheckBox').change(function() {
		setDraggable(this.checked);
	});
	
	$('.styleSelect').change(function() {
		setStyle($(this).val());
	});
	
	// Initialize sortable tables, draggable, and resizeable elements.
	$('table.tablesorter').tablesorter();
	$('.resizable, .tablesWrapper table').resizable();
	
	// Show JavaScript input elements.
	$('.js').show();
	
	// Hide cookie-dependent elements, if cookies are disabled.
	$('.cookie').toggle(isStorageSupported());
	
	// Append current URL to mail bodies.
	$('a.report[href^="mailto:"]').each(function() {
		var $mailLink = $(this);

		var url = window.location.href;
		url = url.substring(0, url.lastIndexOf('/') + 1);

		var mailHref = $mailLink.attr('href');
		var pattern = '&body=';
		mailHref = mailHref.replace(pattern, pattern + escape(url));

		$mailLink.attr('href', mailHref);
	});
});