DROP TABLE IF EXISTS `property`;
DROP TABLE IF EXISTS `attribute_visibility`;
DROP TABLE IF EXISTS `attribute`;
DROP TABLE IF EXISTS `label_item`;
DROP TABLE IF EXISTS `edge_item`;
DROP TABLE IF EXISTS `node_item`;
DROP TABLE IF EXISTS `meta_attributes_to_graphic`;
DROP TABLE IF EXISTS `graphics_to_view`;
DROP TABLE IF EXISTS `mutant_connection`;
DROP TABLE IF EXISTS `mutant_object`;
DROP TABLE IF EXISTS `meta_attribute`;
DROP TABLE IF EXISTS `model`;
DROP TABLE IF EXISTS `project`;
DROP TABLE IF EXISTS `graphic`;
DROP TABLE IF EXISTS `view`;
DROP TABLE IF EXISTS `meta_model`;

--
-- Table structure for table `meta_model`
--
CREATE TABLE `meta_model` (
  `id` varchar(255) NOT NULL,
  `name` varchar(64) NOT NULL,
  `author` varchar(64) DEFAULT NULL,
  `version` int(11) unsigned NOT NULL DEFAULT '1',
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `view`
--
CREATE TABLE `view` (
  `id` varchar(255) NOT NULL,
  `meta_model` varchar(255) NOT NULL,
  `name` varchar(64) NOT NULL,
  `author` varchar(64) DEFAULT NULL,
  `version` int(11) unsigned NOT NULL DEFAULT '1',
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `global` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `FK_VIEW_META_MODEL` (`meta_model`),
  CONSTRAINT `FK_VIEW_META_MODEL` FOREIGN KEY (`meta_model`) REFERENCES `meta_model` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `graphic`
--
CREATE TABLE `graphic` (
  `id` varchar(255) NOT NULL,
  `meta_model` varchar(255) NOT NULL,
  `shape` varchar(255) NOT NULL,
  `path` varchar(255) NOT NULL,
  `type` char(1) NOT NULL DEFAULT 'n',
  PRIMARY KEY (`id`),
  KEY `FK_GRAPHIC_META_MODEL` (`meta_model`),
  CONSTRAINT `FK_GRAPHIC_META_MODEL` FOREIGN KEY (`meta_model`) REFERENCES `meta_model` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `project`
--
CREATE TABLE `project` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `meta_model` varchar(255) DEFAULT NULL,
  `name` varchar(255) NOT NULL,
  `author` varchar(255) DEFAULT NULL,
  `mail` varchar(255) DEFAULT NULL,
  `url` varchar(255) DEFAULT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `description` text,
  PRIMARY KEY (`id`),
  KEY `FK_PROJECT_META_MODEL` (`meta_model`),
  CONSTRAINT `FK_PROJECT_META_MODEL` FOREIGN KEY (`meta_model`) REFERENCES `meta_model` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `model`
--
CREATE TABLE `model` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `project` int(11) unsigned NOT NULL,
  `view` varchar(255) DEFAULT NULL,
  `name` varchar(255) NOT NULL,
  `author` varchar(255) DEFAULT NULL,
  `mail` varchar(255) DEFAULT NULL,
  `url` varchar(255) DEFAULT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `description` text,
  PRIMARY KEY (`id`),
  KEY `FK_MODEL_PROJECT` (`project`),
  KEY `FK_MODEL_VIEW` (`view`),
  CONSTRAINT `FK_MODEL_PROJECT` FOREIGN KEY (`project`) REFERENCES `project` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_MODEL_VIEW` FOREIGN KEY (`view`) REFERENCES `view` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `meta_attribute`
--
CREATE TABLE `meta_attribute` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `at_id` varchar(64) NOT NULL,
  `name` varchar(64) NOT NULL,
  `data_type` varchar(64) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `at_id` (`at_id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `mutant_object`
--
CREATE TABLE `mutant_object` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `mo_id` varchar(64) NOT NULL,
  `default_shape` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `mo_id` (`mo_id`),
  KEY `FK_MUTANT_OBJECT_DEFAULT_GRAPHIC` (`default_shape`),
  CONSTRAINT `FK_MUTANT_OBJECT_DEFAULT_GRAPHIC` FOREIGN KEY (`default_shape`) REFERENCES `graphic` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `mutant_connection`
--
CREATE TABLE `mutant_connection` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `mc_id` varchar(64) NOT NULL,
  `default_shape` varchar(255) DEFAULT NULL,
  `source` int(11) unsigned DEFAULT NULL,
  `target` int(11) unsigned DEFAULT NULL,
  `source_connection` int(11) unsigned DEFAULT NULL,
  `target_connection` int(11) unsigned DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `mc_id` (`mc_id`),
  KEY `FK_MUTANT_CONNECTION_DEFAULT_GRAPHIC` (`default_shape`),
  KEY `FK_MUTANT_CONNECTION_SOURCE_MUTANT_OBJECT` (`source`),
  KEY `FK_MUTANT_CONNECTION_TARGET_MUTANT_OBJECT` (`target`),
  KEY `FK_MUTANT_CONNECTION_SOURCE_MUTANT_CONNECTION` (`source_connection`),
  KEY `FK_MUTANT_CONNECTION_TARGET_MUTANT_CONNECTION` (`target_connection`),
  CONSTRAINT `FK_MUTANT_CONNECTION_DEFAULT_GRAPHIC` FOREIGN KEY (`default_shape`) REFERENCES `graphic` (`id`),
  CONSTRAINT `FK_MUTANT_CONNECTION_SOURCE_MUTANT_CONNECTION` FOREIGN KEY (`source_connection`) REFERENCES `mutant_connection` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_MUTANT_CONNECTION_SOURCE_MUTANT_OBJECT` FOREIGN KEY (`source`) REFERENCES `mutant_object` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_MUTANT_CONNECTION_TARGET_MUTANT_CONNECTION` FOREIGN KEY (`target_connection`) REFERENCES `mutant_connection` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_MUTANT_CONNECTION_TARGET_MUTANT_OBJECT` FOREIGN KEY (`target`) REFERENCES `mutant_object` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `graphics_to_view`
--
CREATE TABLE `graphics_to_view` (
  `id` varchar(255) NOT NULL,
  `view` varchar(255) NOT NULL,
  `graphic` varchar(255) NOT NULL,
  `labeled` tinyint(1) NOT NULL DEFAULT '1',
  `h_align` char(1) DEFAULT '2',
  `v_align` char(1) DEFAULT '2',
  PRIMARY KEY (`id`),
  UNIQUE KEY `view` (`view`,`graphic`),
  KEY `FK_GRAPHICS_TO_VIEW_GRAPHIC` (`graphic`),
  CONSTRAINT `FK_GRAPHICS_TO_VIEW_GRAPHIC` FOREIGN KEY (`graphic`) REFERENCES `graphic` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_GRAPHICS_TO_VIEW_VIEW` FOREIGN KEY (`view`) REFERENCES `view` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `meta_attributes_to_graphic`
--
CREATE TABLE `meta_attributes_to_graphic` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `meta_attribute` int(11) unsigned NOT NULL,
  `graphics_to_view` varchar(255) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `meta_attribute` (`meta_attribute`,`graphics_to_view`),
  KEY `FK_META_ATTRIBUTES_TO_GRAPHIC_GRAPHICS_TO_VIEW` (`graphics_to_view`),
  CONSTRAINT `FK_META_ATTRIBUTES_TO_GRAPHIC_GRAPHICS_TO_VIEW` FOREIGN KEY (`graphics_to_view`) REFERENCES `graphics_to_view` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_META_ATTRIBUTES_TO_GRAPHIC_META_ATTRIBUTE` FOREIGN KEY (`meta_attribute`) REFERENCES `meta_attribute` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `attribute`
--
DROP TABLE IF EXISTS `attribute`;
CREATE TABLE `attribute` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `meta_attribute` int(11) unsigned NOT NULL,
  `mutant_object` int(11) unsigned DEFAULT NULL,
  `mutant_connection` int(11) unsigned DEFAULT NULL,
  `meta_attributes_to_graphic` int(11) unsigned DEFAULT NULL,
  `value` text NOT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_ATTRIBUTE_META_ATTRIBUTE` (`meta_attribute`),
  KEY `FK_ATTRIBUTE_MUTANT_OBJECT` (`mutant_object`),
  KEY `FK_ATTRIBUTE_MUTANT_CONNECTION` (`mutant_connection`),
  KEY `FK_ATTRIBUTE_META_ATTRIBUTES_TO_GRAPHIC` (`meta_attributes_to_graphic`),
  CONSTRAINT `FK_ATTRIBUTE_META_ATTRIBUTE` FOREIGN KEY (`meta_attribute`) REFERENCES `meta_attribute` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_ATTRIBUTE_META_ATTRIBUTES_TO_GRAPHIC` FOREIGN KEY (`meta_attributes_to_graphic`) REFERENCES `meta_attributes_to_graphic` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_ATTRIBUTE_MUTANT_CONNECTION` FOREIGN KEY (`mutant_connection`) REFERENCES `mutant_connection` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_ATTRIBUTE_MUTANT_OBJECT` FOREIGN KEY (`mutant_object`) REFERENCES `mutant_object` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `node_item`
--
CREATE TABLE `node_item` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `model` int(11) unsigned NOT NULL,
  `mutant_object` int(11) unsigned NOT NULL,
  `shape` varchar(255) DEFAULT NULL,
  `parent` int(11) unsigned DEFAULT NULL,
  `x` double DEFAULT NULL,
  `y` double DEFAULT NULL,
  `z` int(11) unsigned DEFAULT '268435456',
  `width` double DEFAULT NULL,
  `height` double DEFAULT NULL,
  `size` double DEFAULT '1',
  `fill_color` int(11) signed DEFAULT NULL,
  `stroke_color` int(11) signed DEFAULT NULL,
  `stroke_width` double DEFAULT NULL,
  `labeled` tinyint(1) DEFAULT '1',
  `visible` tinyint(1) DEFAULT '1',
  `data_group` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_NODE_MODEL` (`model`),
  KEY `FK_NODE_MUTANT_OBJECT` (`mutant_object`),
  KEY `FK_NODE_SHAPE` (`shape`),
  KEY `FK_NODE_PARENT` (`parent`),
  CONSTRAINT `FK_NODE_MODEL` FOREIGN KEY (`model`) REFERENCES `model` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_NODE_MUTANT_OBJECT` FOREIGN KEY (`mutant_object`) REFERENCES `mutant_object` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_NODE_PARENT` FOREIGN KEY (`parent`) REFERENCES `node_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_NODE_SHAPE` FOREIGN KEY (`shape`) REFERENCES `graphic` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `edge_item`
--
CREATE TABLE `edge_item` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `model` int(11) unsigned NOT NULL,
  `mutant_connection` int(11) unsigned NOT NULL,
  `shape` varchar(255) DEFAULT NULL,
  `source` int(11) unsigned DEFAULT NULL,
  `target` int(11) unsigned DEFAULT NULL,
  `source_edge` int(11) unsigned DEFAULT NULL,
  `target_edge` int(11) unsigned DEFAULT NULL,
  `type` int(11) unsigned DEFAULT '0',
  `shape_data` blob,
  `size` double DEFAULT '1',
  `fill_color` int(11) signed DEFAULT NULL,
  `stroke_color` int(11) signed DEFAULT NULL,
  `stroke_width` double DEFAULT NULL,
  `labeled` tinyint(1) DEFAULT '1',
  `visible` tinyint(1) DEFAULT '1',
  `data_group` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `FK_EDGE_MODEL` (`model`),
  KEY `FK_EDGE_MUTANT_CONNECTION` (`mutant_connection`),
  KEY `FK_EDGE_GRAPHIC` (`shape`),
  KEY `FK_EDGE_SOURCE_NODE` (`source`),
  KEY `FK_EDGE_TARGET_NODE` (`target`),
  KEY `FK_EDGE_SOURCE_EDGE` (`source_edge`),
  KEY `FK_EDGE_TARGET_EDGE` (`target_edge`),
  CONSTRAINT `FK_EDGE_GRAPHIC` FOREIGN KEY (`shape`) REFERENCES `graphic` (`id`),
  CONSTRAINT `FK_EDGE_MODEL` FOREIGN KEY (`model`) REFERENCES `model` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_EDGE_MUTANT_CONNECTION` FOREIGN KEY (`mutant_connection`) REFERENCES `mutant_connection` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_EDGE_SOURCE_EDGE` FOREIGN KEY (`source_edge`) REFERENCES `edge_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_EDGE_SOURCE_NODE` FOREIGN KEY (`source`) REFERENCES `node_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_EDGE_TARGET_EDGE` FOREIGN KEY (`target_edge`) REFERENCES `edge_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_EDGE_TARGET_NODE` FOREIGN KEY (`target`) REFERENCES `node_item` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `label_item`
--
CREATE TABLE `label_item` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `node` int(11) unsigned DEFAULT NULL,
  `edge` int(11) unsigned DEFAULT NULL,
  `text` text,
  `x` double DEFAULT NULL,
  `y` double DEFAULT NULL,
  `font` varchar(255) DEFAULT NULL,
  `font_color` int(11) signed DEFAULT NULL,
  `font_size` int(11) unsigned DEFAULT '10',
  `visible` tinyint(1) DEFAULT '1',
  `h_align` char(1) DEFAULT '2',
  `v_align` char(1) DEFAULT '2',
  PRIMARY KEY (`id`),
  KEY `FK_LABEL_NODE` (`node`),
  KEY `FK_LABEL_EDGE` (`edge`),
  CONSTRAINT `FK_LABEL_EDGE` FOREIGN KEY (`edge`) REFERENCES `edge_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_LABEL_NODE` FOREIGN KEY (`node`) REFERENCES `node_item` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `attribute_visibility`
--
CREATE TABLE `attribute_visibility` (
  `attribute` int(11) unsigned NOT NULL,
  `node` int(11) unsigned DEFAULT NULL,
  `edge` int(11) unsigned DEFAULT NULL,
  UNIQUE KEY `attribute` (`attribute`,`node`,`edge`),
  KEY `FK_ATTRIBUTE_VISIBILITY_NODE` (`node`),
  KEY `FK_ATTRIBUTE_VISIBILITY_EDGE` (`edge`),
  CONSTRAINT `FK_ATTRIBUTE_VISIBILITY_ATTRIBUTE` FOREIGN KEY (`attribute`) REFERENCES `attribute` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_ATTRIBUTE_VISIBILITY_EDGE` FOREIGN KEY (`edge`) REFERENCES `edge_item` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_ATTRIBUTE_VISIBILITY_NODE` FOREIGN KEY (`node`) REFERENCES `node_item` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `property`
--
CREATE TABLE `property` (
  `name` varchar(255) NOT NULL,
  `value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;



--
-- Table structure for table `comm`
--
DROP TABLE IF EXISTS `comm`;
CREATE TABLE `comm` (
  `commId` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  PRIMARY KEY (`commId`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=latin1;

--
-- Dumping data for table `comm`
--
LOCK TABLES `comm` WRITE;
INSERT INTO `comm` VALUES (1,'E-Mail'),(2,'Persönliches Gespräch'),(3,'Sametime'),(4,'Skype'),(5,'Telefon');
UNLOCK TABLES;

--
-- Table structure for table `event`
--
DROP TABLE IF EXISTS `event`;
CREATE TABLE `event` (
  `eventId` int(11) NOT NULL AUTO_INCREMENT,
  `message` text NOT NULL,
  `timeCreated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `ip` varchar(255) DEFAULT NULL,
  `userAgent` varchar(1024) DEFAULT NULL,
  PRIMARY KEY (`eventId`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=latin1;

--
-- Table structure for table `location`
--
DROP TABLE IF EXISTS `location`;
CREATE TABLE `location` (
  `locationId` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `timeCreated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`locationId`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=latin1;

--
-- Dumping data for table `location`
--
LOCK TABLES `location` WRITE;
INSERT INTO `location` VALUES (1,'Babelsberg','2013-06-05 18:45:26'),(2,'Babelsberg (Lupo-Labor)','2013-06-05 18:45:44'),(3,'Griebnitzsee','2013-06-05 18:45:54'),(4,'Berlin, Gito-Verlag','2013-06-05 18:46:29'),(5,'Gattendorf, Büro','2013-06-05 19:03:35'),(6,'Zedtwitz (Home Office)','2013-06-05 19:04:43');
UNLOCK TABLES;

--
-- Table structure for table `task`
--
DROP TABLE IF EXISTS `task`;
CREATE TABLE `task` (
  `taskId` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `timeCreated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`taskId`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1;

--
-- Dumping data for table `task`
--
LOCK TABLES `task` WRITE;
INSERT INTO `task` VALUES (1,'Lupo-Fortsetzung','2013-06-05 18:47:40'),(2,'KMDL Zeit-Ortsvektoren','2013-06-05 18:48:50'),(3,'ERP-Labor','2013-06-05 18:49:38');
UNLOCK TABLES;
